# $Id: smd.tcl,v 1.2 2005/02/18 18:07:11 mbach Exp $

# Atoms selected for force application 
# "BH" is molecule name (probably "PEP" or "PRO0")
set id1 [atomid MAIN 1 CA]
set grp1 {}
lappend grp1 $id1
set a1 [addgroup $grp1]

set id2 [atomid MAIN 58 CA]
set grp2 {}
lappend grp2 $id2
set a2 [addgroup $grp2]

# set the output frequency, initialize the time counter
set Tclfreq 50
set t 0

# constraint points
# these should closely match actual positions.
# a13 gives a distance via VMD of 19.61
set c1x 39.872
set c1y 20.811
set c1z 8.488

set c2x 42.060
set c2y 24.023
set c2z 4.656

# force constant (kcal/mol/A^2)
set k 7.2

# pulling velocity (A/timestep)
set v 0.005

set outfilename 1qlq_smd_tcl.out
open $outfilename w

proc calcforces {} {

  global Tclfreq t k v a1 a2 c1x c1y c1z c2x c2y c2z outfilename

  # get coordinates

  loadcoords coordinate

  set r1 $coordinate($a1)
  set r1x [lindex $r1 0]
  set r1y [lindex $r1 1]
  set r1z [lindex $r1 2]

  set r2 $coordinate($a2)
  set r2x [lindex $r2 0]
  set r2y [lindex $r2 1]
  set r2z [lindex $r2 2]

  # calculate forces

  set f1x [expr $k*($c1x-$r1x)]
  set f1y [expr $k*($c1y-$r1y)]
  set f1z [expr $k*($c1z-$r1z)]
  lappend f1 $f1x $f1y $f1z

  set f2x [expr $k*($c2x-$r2x)]
  set f2y [expr $k*($c2y-$r2y)]
  set f2z [expr $k*($c2z+$v*$t-$r2z)]
  lappend f2 $f2x $f2y $f2z

  # apply forces

  addforce $a1 $f1
  addforce $a2 $f2

  # output

  set foo [expr $t % $Tclfreq]
  if { $foo == 0 } {
      set outfile [open $outfilename a]
      set time [expr $t*2/1000.0]
#      MODIFIED to provide units in pN
#      1 kcal/mol A = 69.48 pN
#      also because r1z is not 0.0, need to find true distance
      puts $outfile "$time [expr $r2z - $r1z] [expr $f2z * 69.48]"
#     puts $outfile "$time $r2z $f2z"
      close $outfile
  }
  incr t
  return
}
